# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.12 Python SDK

    Pure Storage FlashBlade REST 1.12 Python SDK. Compatible with REST API versions 1.0 - 1.12. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.12
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SnmpAgent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'engine_id': 'str',
        'version': 'str',
        'v2c': 'SnmpV2c',
        'v3': 'SnmpV3'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'engine_id': 'engine_id',
        'version': 'version',
        'v2c': 'v2c',
        'v3': 'v3'
    }

    def __init__(self, id=None, name=None, engine_id=None, version=None, v2c=None, v3=None):  # noqa: E501
        """SnmpAgent - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._engine_id = None
        self._version = None
        self._v2c = None
        self._v3 = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if engine_id is not None:
            self.engine_id = engine_id
        if version is not None:
            self.version = version
        if v2c is not None:
            self.v2c = v2c
        if v3 is not None:
            self.v3 = v3

    @property
    def id(self):
        """Gets the id of this SnmpAgent.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this SnmpAgent.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SnmpAgent.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this SnmpAgent.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this SnmpAgent.  # noqa: E501

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :return: The name of this SnmpAgent.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SnmpAgent.

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :param name: The name of this SnmpAgent.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def engine_id(self):
        """Gets the engine_id of this SnmpAgent.  # noqa: E501

        An SNMP engine's administratively-unique identifier.  # noqa: E501

        :return: The engine_id of this SnmpAgent.  # noqa: E501
        :rtype: str
        """
        return self._engine_id

    @engine_id.setter
    def engine_id(self, engine_id):
        """Sets the engine_id of this SnmpAgent.

        An SNMP engine's administratively-unique identifier.  # noqa: E501

        :param engine_id: The engine_id of this SnmpAgent.  # noqa: E501
        :type: str
        """
        if engine_id is not None and len(engine_id) > 32:
            raise ValueError("Invalid value for `engine_id`, length must be less than or equal to `32`")  # noqa: E501

        self._engine_id = engine_id

    @property
    def version(self):
        """Gets the version of this SnmpAgent.  # noqa: E501

        Version of the SNMP protocol to be used by an SNMP manager in communications with Purity's SNMP agent. Valid values are `v2c` and `v3`.  # noqa: E501

        :return: The version of this SnmpAgent.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SnmpAgent.

        Version of the SNMP protocol to be used by an SNMP manager in communications with Purity's SNMP agent. Valid values are `v2c` and `v3`.  # noqa: E501

        :param version: The version of this SnmpAgent.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def v2c(self):
        """Gets the v2c of this SnmpAgent.  # noqa: E501


        :return: The v2c of this SnmpAgent.  # noqa: E501
        :rtype: SnmpV2c
        """
        return self._v2c

    @v2c.setter
    def v2c(self, v2c):
        """Sets the v2c of this SnmpAgent.


        :param v2c: The v2c of this SnmpAgent.  # noqa: E501
        :type: SnmpV2c
        """

        self._v2c = v2c

    @property
    def v3(self):
        """Gets the v3 of this SnmpAgent.  # noqa: E501


        :return: The v3 of this SnmpAgent.  # noqa: E501
        :rtype: SnmpV3
        """
        return self._v3

    @v3.setter
    def v3(self, v3):
        """Sets the v3 of this SnmpAgent.


        :param v3: The v3 of this SnmpAgent.  # noqa: E501
        :type: SnmpV3
        """

        self._v3 = v3

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SnmpAgent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SnmpAgent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.6 Python SDK

    Pure Storage FlashBlade REST 1.6 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.6
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AdminApiToken(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created': 'int',
        'expires': 'int',
        'token': 'str'
    }

    attribute_map = {
        'created': 'created',
        'expires': 'expires',
        'token': 'token'
    }

    def __init__(self, created=None, expires=None, token=None):  # noqa: E501
        """AdminApiToken - a model defined in Swagger"""  # noqa: E501

        self._created = None
        self._expires = None
        self._token = None
        self.discriminator = None

        if created is not None:
            self.created = created
        if expires is not None:
            self.expires = expires
        if token is not None:
            self.token = token

    @property
    def created(self):
        """Gets the created of this AdminApiToken.  # noqa: E501

        Creation time in milliseconds since UNIX epoch  # noqa: E501

        :return: The created of this AdminApiToken.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this AdminApiToken.

        Creation time in milliseconds since UNIX epoch  # noqa: E501

        :param created: The created of this AdminApiToken.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def expires(self):
        """Gets the expires of this AdminApiToken.  # noqa: E501

        Expiration time in milliseconds since UNIX epoch  # noqa: E501

        :return: The expires of this AdminApiToken.  # noqa: E501
        :rtype: int
        """
        return self._expires

    @expires.setter
    def expires(self, expires):
        """Sets the expires of this AdminApiToken.

        Expiration time in milliseconds since UNIX epoch  # noqa: E501

        :param expires: The expires of this AdminApiToken.  # noqa: E501
        :type: int
        """

        self._expires = expires

    @property
    def token(self):
        """Gets the token of this AdminApiToken.  # noqa: E501

        Admin API token  # noqa: E501

        :return: The token of this AdminApiToken.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this AdminApiToken.

        Admin API token  # noqa: E501

        :param token: The token of this AdminApiToken.  # noqa: E501
        :type: str
        """

        self._token = token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AdminApiToken, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdminApiToken):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.12 Python SDK

    Pure Storage FlashBlade REST 1.12 Python SDK. Compatible with REST API versions 1.0 - 1.12. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.12
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AlertWatcherPost(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'minimum_notification_severity': 'str'
    }

    attribute_map = {
        'minimum_notification_severity': 'minimum_notification_severity'
    }

    def __init__(self, minimum_notification_severity=None):  # noqa: E501
        """AlertWatcherPost - a model defined in Swagger"""  # noqa: E501

        self._minimum_notification_severity = None
        self.discriminator = None

        if minimum_notification_severity is not None:
            self.minimum_notification_severity = minimum_notification_severity

    @property
    def minimum_notification_severity(self):
        """Gets the minimum_notification_severity of this AlertWatcherPost.  # noqa: E501

        The minimum severity that an alert must have in order for emails to be sent to the array's alert watchers. Possible values include 'info', 'warning', and 'critical'. Defaults to 'info' if not specified.  # noqa: E501

        :return: The minimum_notification_severity of this AlertWatcherPost.  # noqa: E501
        :rtype: str
        """
        return self._minimum_notification_severity

    @minimum_notification_severity.setter
    def minimum_notification_severity(self, minimum_notification_severity):
        """Sets the minimum_notification_severity of this AlertWatcherPost.

        The minimum severity that an alert must have in order for emails to be sent to the array's alert watchers. Possible values include 'info', 'warning', and 'critical'. Defaults to 'info' if not specified.  # noqa: E501

        :param minimum_notification_severity: The minimum_notification_severity of this AlertWatcherPost.  # noqa: E501
        :type: str
        """

        self._minimum_notification_severity = minimum_notification_severity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AlertWatcherPost, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlertWatcherPost):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.8.1 Python SDK

    Pure Storage FlashBlade REST 1.8.1 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.8.1
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CertificatePost(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'certificate': 'str',
        'certificate_type': 'str',
        'intermediate_certificate': 'str',
        'passphrase': 'str',
        'private_key': 'str'
    }

    attribute_map = {
        'name': 'name',
        'certificate': 'certificate',
        'certificate_type': 'certificate_type',
        'intermediate_certificate': 'intermediate_certificate',
        'passphrase': 'passphrase',
        'private_key': 'private_key'
    }

    def __init__(self, name=None, certificate=None, certificate_type=None, intermediate_certificate=None, passphrase=None, private_key=None):  # noqa: E501
        """CertificatePost - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._certificate = None
        self._certificate_type = None
        self._intermediate_certificate = None
        self._passphrase = None
        self._private_key = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if certificate is not None:
            self.certificate = certificate
        if certificate_type is not None:
            self.certificate_type = certificate_type
        if intermediate_certificate is not None:
            self.intermediate_certificate = intermediate_certificate
        if passphrase is not None:
            self.passphrase = passphrase
        if private_key is not None:
            self.private_key = private_key

    @property
    def name(self):
        """Gets the name of this CertificatePost.  # noqa: E501

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :return: The name of this CertificatePost.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CertificatePost.

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :param name: The name of this CertificatePost.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def certificate(self):
        """Gets the certificate of this CertificatePost.  # noqa: E501

        The text of the certificate.  # noqa: E501

        :return: The certificate of this CertificatePost.  # noqa: E501
        :rtype: str
        """
        return self._certificate

    @certificate.setter
    def certificate(self, certificate):
        """Sets the certificate of this CertificatePost.

        The text of the certificate.  # noqa: E501

        :param certificate: The certificate of this CertificatePost.  # noqa: E501
        :type: str
        """

        self._certificate = certificate

    @property
    def certificate_type(self):
        """Gets the certificate_type of this CertificatePost.  # noqa: E501

        The type of certificate. Possible values are `array` and `external`. Certificates of type `array` are used by the array to verify its identity to clients. Certificates of type `external` are used by the array to identify external servers to which it is configured to communicate.  # noqa: E501

        :return: The certificate_type of this CertificatePost.  # noqa: E501
        :rtype: str
        """
        return self._certificate_type

    @certificate_type.setter
    def certificate_type(self, certificate_type):
        """Sets the certificate_type of this CertificatePost.

        The type of certificate. Possible values are `array` and `external`. Certificates of type `array` are used by the array to verify its identity to clients. Certificates of type `external` are used by the array to identify external servers to which it is configured to communicate.  # noqa: E501

        :param certificate_type: The certificate_type of this CertificatePost.  # noqa: E501
        :type: str
        """

        self._certificate_type = certificate_type

    @property
    def intermediate_certificate(self):
        """Gets the intermediate_certificate of this CertificatePost.  # noqa: E501

        Intermediate certificate chains.  # noqa: E501

        :return: The intermediate_certificate of this CertificatePost.  # noqa: E501
        :rtype: str
        """
        return self._intermediate_certificate

    @intermediate_certificate.setter
    def intermediate_certificate(self, intermediate_certificate):
        """Sets the intermediate_certificate of this CertificatePost.

        Intermediate certificate chains.  # noqa: E501

        :param intermediate_certificate: The intermediate_certificate of this CertificatePost.  # noqa: E501
        :type: str
        """

        self._intermediate_certificate = intermediate_certificate

    @property
    def passphrase(self):
        """Gets the passphrase of this CertificatePost.  # noqa: E501

        The passphrase used to encrypt the private key.  # noqa: E501

        :return: The passphrase of this CertificatePost.  # noqa: E501
        :rtype: str
        """
        return self._passphrase

    @passphrase.setter
    def passphrase(self, passphrase):
        """Sets the passphrase of this CertificatePost.

        The passphrase used to encrypt the private key.  # noqa: E501

        :param passphrase: The passphrase of this CertificatePost.  # noqa: E501
        :type: str
        """

        self._passphrase = passphrase

    @property
    def private_key(self):
        """Gets the private_key of this CertificatePost.  # noqa: E501

        The private key used to sign the certificate.  # noqa: E501

        :return: The private_key of this CertificatePost.  # noqa: E501
        :rtype: str
        """
        return self._private_key

    @private_key.setter
    def private_key(self, private_key):
        """Sets the private_key of this CertificatePost.

        The private key used to sign the certificate.  # noqa: E501

        :param private_key: The private_key of this CertificatePost.  # noqa: E501
        :type: str
        """

        self._private_key = private_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CertificatePost, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CertificatePost):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.11 Python SDK

    Pure Storage FlashBlade REST 1.11 Python SDK. Compatible with REST API versions 1.0 - 1.11. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.11
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class HardwareConnector(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'connector_type': 'str',
        'lane_speed': 'int',
        'port_count': 'int',
        'transceiver_type': 'str'
    }

    attribute_map = {
        'name': 'name',
        'connector_type': 'connector_type',
        'lane_speed': 'lane_speed',
        'port_count': 'port_count',
        'transceiver_type': 'transceiver_type'
    }

    def __init__(self, name=None, connector_type=None, lane_speed=None, port_count=None, transceiver_type=None):  # noqa: E501
        """HardwareConnector - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._connector_type = None
        self._lane_speed = None
        self._port_count = None
        self._transceiver_type = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if connector_type is not None:
            self.connector_type = connector_type
        if lane_speed is not None:
            self.lane_speed = lane_speed
        if port_count is not None:
            self.port_count = port_count
        if transceiver_type is not None:
            self.transceiver_type = transceiver_type

    @property
    def name(self):
        """Gets the name of this HardwareConnector.  # noqa: E501

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :return: The name of this HardwareConnector.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this HardwareConnector.

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :param name: The name of this HardwareConnector.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def connector_type(self):
        """Gets the connector_type of this HardwareConnector.  # noqa: E501

        Form-factor of the interface. Valid values include QSFP and RJ-45.  # noqa: E501

        :return: The connector_type of this HardwareConnector.  # noqa: E501
        :rtype: str
        """
        return self._connector_type

    @connector_type.setter
    def connector_type(self, connector_type):
        """Sets the connector_type of this HardwareConnector.

        Form-factor of the interface. Valid values include QSFP and RJ-45.  # noqa: E501

        :param connector_type: The connector_type of this HardwareConnector.  # noqa: E501
        :type: str
        """

        self._connector_type = connector_type

    @property
    def lane_speed(self):
        """Gets the lane_speed of this HardwareConnector.  # noqa: E501

        Configured speed of each lane in the connector in bits-per-second  # noqa: E501

        :return: The lane_speed of this HardwareConnector.  # noqa: E501
        :rtype: int
        """
        return self._lane_speed

    @lane_speed.setter
    def lane_speed(self, lane_speed):
        """Sets the lane_speed of this HardwareConnector.

        Configured speed of each lane in the connector in bits-per-second  # noqa: E501

        :param lane_speed: The lane_speed of this HardwareConnector.  # noqa: E501
        :type: int
        """

        self._lane_speed = lane_speed

    @property
    def port_count(self):
        """Gets the port_count of this HardwareConnector.  # noqa: E501

        Configured number of ports in the connector. (1/2/4 for QSFP)  # noqa: E501

        :return: The port_count of this HardwareConnector.  # noqa: E501
        :rtype: int
        """
        return self._port_count

    @port_count.setter
    def port_count(self, port_count):
        """Sets the port_count of this HardwareConnector.

        Configured number of ports in the connector. (1/2/4 for QSFP)  # noqa: E501

        :param port_count: The port_count of this HardwareConnector.  # noqa: E501
        :type: int
        """

        self._port_count = port_count

    @property
    def transceiver_type(self):
        """Gets the transceiver_type of this HardwareConnector.  # noqa: E501

        Details about the transceiver which is plugged into the connector port. Transceiver type will be read-only for Pureuser. If nothing is plugged into QSFP port, value will be “Unused”. If a transceiver is plugged in, and type cannot be auto-detected,  and internal user has not specified a type - value will be “Unknown”. If transceiver is plugged in, and type is auto-detected, and/or type has been explicitly set by internal user - that value will be shown. Transceiver type is not applicable for RJ-45 connectors.  # noqa: E501

        :return: The transceiver_type of this HardwareConnector.  # noqa: E501
        :rtype: str
        """
        return self._transceiver_type

    @transceiver_type.setter
    def transceiver_type(self, transceiver_type):
        """Sets the transceiver_type of this HardwareConnector.

        Details about the transceiver which is plugged into the connector port. Transceiver type will be read-only for Pureuser. If nothing is plugged into QSFP port, value will be “Unused”. If a transceiver is plugged in, and type cannot be auto-detected,  and internal user has not specified a type - value will be “Unknown”. If transceiver is plugged in, and type is auto-detected, and/or type has been explicitly set by internal user - that value will be shown. Transceiver type is not applicable for RJ-45 connectors.  # noqa: E501

        :param transceiver_type: The transceiver_type of this HardwareConnector.  # noqa: E501
        :type: str
        """

        self._transceiver_type = transceiver_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HardwareConnector, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HardwareConnector):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.10 Python SDK

    Pure Storage FlashBlade REST 1.10 Python SDK. Compatible with REST API versions 1.0 - 1.10. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.10
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ArrayConnection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'ca_certificate_group': 'FixedReferenceWithId',
        'management_address': 'str',
        'replication_addresses': 'list[str]',
        'status': 'str',
        'encrypted': 'bool',
        'remote': 'FixedReferenceNoResourceType',
        'version': 'str'
    }

    attribute_map = {
        'id': 'id',
        'ca_certificate_group': 'ca_certificate_group',
        'management_address': 'management_address',
        'replication_addresses': 'replication_addresses',
        'status': 'status',
        'encrypted': 'encrypted',
        'remote': 'remote',
        'version': 'version'
    }

    def __init__(self, id=None, ca_certificate_group=None, management_address=None, replication_addresses=None, status=None, encrypted=False, remote=None, version=None):  # noqa: E501
        """ArrayConnection - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._ca_certificate_group = None
        self._management_address = None
        self._replication_addresses = None
        self._status = None
        self._encrypted = None
        self._remote = None
        self._version = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if ca_certificate_group is not None:
            self.ca_certificate_group = ca_certificate_group
        if management_address is not None:
            self.management_address = management_address
        if replication_addresses is not None:
            self.replication_addresses = replication_addresses
        if status is not None:
            self.status = status
        if encrypted is not None:
            self.encrypted = encrypted
        if remote is not None:
            self.remote = remote
        if version is not None:
            self.version = version

    @property
    def id(self):
        """Gets the id of this ArrayConnection.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this ArrayConnection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ArrayConnection.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this ArrayConnection.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ca_certificate_group(self):
        """Gets the ca_certificate_group of this ArrayConnection.  # noqa: E501

        The group of CA certificates that can be used, in addition to well-known Certificate Authority certificates, in order to establish a secure connection to the target array. Defaults to a reference to the _default_replication_certs group if secure_connection is true, or null otherwise.  # noqa: E501

        :return: The ca_certificate_group of this ArrayConnection.  # noqa: E501
        :rtype: FixedReferenceWithId
        """
        return self._ca_certificate_group

    @ca_certificate_group.setter
    def ca_certificate_group(self, ca_certificate_group):
        """Sets the ca_certificate_group of this ArrayConnection.

        The group of CA certificates that can be used, in addition to well-known Certificate Authority certificates, in order to establish a secure connection to the target array. Defaults to a reference to the _default_replication_certs group if secure_connection is true, or null otherwise.  # noqa: E501

        :param ca_certificate_group: The ca_certificate_group of this ArrayConnection.  # noqa: E501
        :type: FixedReferenceWithId
        """

        self._ca_certificate_group = ca_certificate_group

    @property
    def management_address(self):
        """Gets the management_address of this ArrayConnection.  # noqa: E501

        Management address of the target array. Settable on POST only. Modifiable only on the source.  # noqa: E501

        :return: The management_address of this ArrayConnection.  # noqa: E501
        :rtype: str
        """
        return self._management_address

    @management_address.setter
    def management_address(self, management_address):
        """Sets the management_address of this ArrayConnection.

        Management address of the target array. Settable on POST only. Modifiable only on the source.  # noqa: E501

        :param management_address: The management_address of this ArrayConnection.  # noqa: E501
        :type: str
        """

        self._management_address = management_address

    @property
    def replication_addresses(self):
        """Gets the replication_addresses of this ArrayConnection.  # noqa: E501

        IP addresses and/or FQDNs of the target arrays. Settable on POST only. If not set on POST, will be set to all the replication addresses available on the target array at the time of the POST.  # noqa: E501

        :return: The replication_addresses of this ArrayConnection.  # noqa: E501
        :rtype: list[str]
        """
        return self._replication_addresses

    @replication_addresses.setter
    def replication_addresses(self, replication_addresses):
        """Sets the replication_addresses of this ArrayConnection.

        IP addresses and/or FQDNs of the target arrays. Settable on POST only. If not set on POST, will be set to all the replication addresses available on the target array at the time of the POST.  # noqa: E501

        :param replication_addresses: The replication_addresses of this ArrayConnection.  # noqa: E501
        :type: list[str]
        """

        self._replication_addresses = replication_addresses

    @property
    def status(self):
        """Gets the status of this ArrayConnection.  # noqa: E501

        Status of the connection. Valid values are `connected`, `partially_connected`, `connecting`, and `incompatible`. `connected` - The connection is OK. `partially_connected` - Some replication addresses are working, but others are not. `connecting` - No connection exists and the array is trying to reconnect. `incompatible` - The target array is not compatible.  # noqa: E501

        :return: The status of this ArrayConnection.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ArrayConnection.

        Status of the connection. Valid values are `connected`, `partially_connected`, `connecting`, and `incompatible`. `connected` - The connection is OK. `partially_connected` - Some replication addresses are working, but others are not. `connecting` - No connection exists and the array is trying to reconnect. `incompatible` - The target array is not compatible.  # noqa: E501

        :param status: The status of this ArrayConnection.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def encrypted(self):
        """Gets the encrypted of this ArrayConnection.  # noqa: E501

        If this is set to true, then all customer data replicated over the connection will be sent over an encrypted connection using TLS, or will not be sent if a secure connection cannot be established. If this is set to false, then all customer data replicated over the connection will be sent over an unencrypted connection. Defaults to false.  # noqa: E501

        :return: The encrypted of this ArrayConnection.  # noqa: E501
        :rtype: bool
        """
        return self._encrypted

    @encrypted.setter
    def encrypted(self, encrypted):
        """Sets the encrypted of this ArrayConnection.

        If this is set to true, then all customer data replicated over the connection will be sent over an encrypted connection using TLS, or will not be sent if a secure connection cannot be established. If this is set to false, then all customer data replicated over the connection will be sent over an unencrypted connection. Defaults to false.  # noqa: E501

        :param encrypted: The encrypted of this ArrayConnection.  # noqa: E501
        :type: bool
        """

        self._encrypted = encrypted

    @property
    def remote(self):
        """Gets the remote of this ArrayConnection.  # noqa: E501

        The remote array.  # noqa: E501

        :return: The remote of this ArrayConnection.  # noqa: E501
        :rtype: FixedReferenceNoResourceType
        """
        return self._remote

    @remote.setter
    def remote(self, remote):
        """Sets the remote of this ArrayConnection.

        The remote array.  # noqa: E501

        :param remote: The remote of this ArrayConnection.  # noqa: E501
        :type: FixedReferenceNoResourceType
        """

        self._remote = remote

    @property
    def version(self):
        """Gets the version of this ArrayConnection.  # noqa: E501

        The version of the target array.  # noqa: E501

        :return: The version of this ArrayConnection.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ArrayConnection.

        The version of the target array.  # noqa: E501

        :param version: The version of this ArrayConnection.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ArrayConnection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ArrayConnection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.2 Python SDK

    Pure Storage FlashBlade REST 1.2 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.2
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ArraySpace(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'capacity': 'int',
        'parity': 'float',
        'space': 'Space',
        'time': 'int'
    }

    attribute_map = {
        'name': 'name',
        'capacity': 'capacity',
        'parity': 'parity',
        'space': 'space',
        'time': 'time'
    }

    def __init__(self, name=None, capacity=None, parity=None, space=None, time=None):  # noqa: E501
        """ArraySpace - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._capacity = None
        self._parity = None
        self._space = None
        self._time = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if capacity is not None:
            self.capacity = capacity
        if parity is not None:
            self.parity = parity
        if space is not None:
            self.space = space
        if time is not None:
            self.time = time

    @property
    def name(self):
        """Gets the name of this ArraySpace.  # noqa: E501

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :return: The name of this ArraySpace.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ArraySpace.

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :param name: The name of this ArraySpace.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def capacity(self):
        """Gets the capacity of this ArraySpace.  # noqa: E501

        usable capacity in bytes  # noqa: E501

        :return: The capacity of this ArraySpace.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this ArraySpace.

        usable capacity in bytes  # noqa: E501

        :param capacity: The capacity of this ArraySpace.  # noqa: E501
        :type: int
        """

        self._capacity = capacity

    @property
    def parity(self):
        """Gets the parity of this ArraySpace.  # noqa: E501


        :return: The parity of this ArraySpace.  # noqa: E501
        :rtype: float
        """
        return self._parity

    @parity.setter
    def parity(self, parity):
        """Sets the parity of this ArraySpace.


        :param parity: The parity of this ArraySpace.  # noqa: E501
        :type: float
        """

        self._parity = parity

    @property
    def space(self):
        """Gets the space of this ArraySpace.  # noqa: E501

        the space measurement of the array  # noqa: E501

        :return: The space of this ArraySpace.  # noqa: E501
        :rtype: Space
        """
        return self._space

    @space.setter
    def space(self, space):
        """Sets the space of this ArraySpace.

        the space measurement of the array  # noqa: E501

        :param space: The space of this ArraySpace.  # noqa: E501
        :type: Space
        """

        self._space = space

    @property
    def time(self):
        """Gets the time of this ArraySpace.  # noqa: E501

        Sample time in milliseconds since UNIX epoch  # noqa: E501

        :return: The time of this ArraySpace.  # noqa: E501
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this ArraySpace.

        Sample time in milliseconds since UNIX epoch  # noqa: E501

        :param time: The time of this ArraySpace.  # noqa: E501
        :type: int
        """

        self._time = time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ArraySpace, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ArraySpace):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.5 Python SDK

    Pure Storage FlashBlade REST 1.5 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.5
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class ObjectStoreUsersApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def create_object_store_users(self, **kwargs):
        """
        Create a new object store user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_object_store_users(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :return: ObjectStoreUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_object_store_users_with_http_info(**kwargs)
        else:
            (data) = self.create_object_store_users_with_http_info(**kwargs)
            return data

    def create_object_store_users_with_http_info(self, **kwargs):
        """
        Create a new object store user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_object_store_users_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :return: ObjectStoreUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['names']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_object_store_users" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'names' in params:
            query_params.append(('names', params['names']))
            collection_formats['names'] = 'csv'

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.5/object-store-users', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='ObjectStoreUserResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def delete_object_store_users(self, **kwargs):
        """
        Delete an object store user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_object_store_users(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_object_store_users_with_http_info(**kwargs)
        else:
            (data) = self.delete_object_store_users_with_http_info(**kwargs)
            return data

    def delete_object_store_users_with_http_info(self, **kwargs):
        """
        Delete an object store user
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_object_store_users_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['names']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_object_store_users" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'names' in params:
            query_params.append(('names', params['names']))
            collection_formats['names'] = 'csv'

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.5/object-store-users', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def list_object_store_users(self, **kwargs):
        """
        List object store users
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_object_store_users(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str filter: The filter to be used for query.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start: The offset of the first resource to return from a collection.
        :param int limit: limit, should be >= 0
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :return: ObjectStoreUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_object_store_users_with_http_info(**kwargs)
        else:
            (data) = self.list_object_store_users_with_http_info(**kwargs)
            return data

    def list_object_store_users_with_http_info(self, **kwargs):
        """
        List object store users
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_object_store_users_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str filter: The filter to be used for query.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start: The offset of the first resource to return from a collection.
        :param int limit: limit, should be >= 0
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :return: ObjectStoreUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'sort', 'start', 'limit', 'token', 'names']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_object_store_users" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('filter', params['filter']))
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'start' in params:
            query_params.append(('start', params['start']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'token' in params:
            query_params.append(('token', params['token']))
        if 'names' in params:
            query_params.append(('names', params['names']))
            collection_formats['names'] = 'csv'

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.5/object-store-users', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='ObjectStoreUserResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.8 Python SDK

    Pure Storage FlashBlade REST 1.8 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.8
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Subnet(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'enabled': 'bool',
        'gateway': 'str',
        'interfaces': 'list[Reference]',
        'link_aggregation_group': 'Reference',
        'mtu': 'int',
        'prefix': 'str',
        'services': 'list[str]',
        'vlan': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'enabled': 'enabled',
        'gateway': 'gateway',
        'interfaces': 'interfaces',
        'link_aggregation_group': 'link_aggregation_group',
        'mtu': 'mtu',
        'prefix': 'prefix',
        'services': 'services',
        'vlan': 'vlan'
    }

    def __init__(self, id=None, name=None, enabled=None, gateway=None, interfaces=None, link_aggregation_group=None, mtu=None, prefix=None, services=None, vlan=None):  # noqa: E501
        """Subnet - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._enabled = None
        self._gateway = None
        self._interfaces = None
        self._link_aggregation_group = None
        self._mtu = None
        self._prefix = None
        self._services = None
        self._vlan = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if enabled is not None:
            self.enabled = enabled
        if gateway is not None:
            self.gateway = gateway
        if interfaces is not None:
            self.interfaces = interfaces
        if link_aggregation_group is not None:
            self.link_aggregation_group = link_aggregation_group
        if mtu is not None:
            self.mtu = mtu
        if prefix is not None:
            self.prefix = prefix
        if services is not None:
            self.services = services
        if vlan is not None:
            self.vlan = vlan

    @property
    def id(self):
        """Gets the id of this Subnet.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this Subnet.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Subnet.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this Subnet.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Subnet.  # noqa: E501

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :return: The name of this Subnet.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Subnet.

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :param name: The name of this Subnet.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def enabled(self):
        """Gets the enabled of this Subnet.  # noqa: E501

        Indicates if subnet is enabled (true) or disabled (false). Enabled by default.  # noqa: E501

        :return: The enabled of this Subnet.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this Subnet.

        Indicates if subnet is enabled (true) or disabled (false). Enabled by default.  # noqa: E501

        :param enabled: The enabled of this Subnet.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def gateway(self):
        """Gets the gateway of this Subnet.  # noqa: E501

        The IPv4 or IPv6 address of the gateway through which the specified subnet is to communicate with the network.  # noqa: E501

        :return: The gateway of this Subnet.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this Subnet.

        The IPv4 or IPv6 address of the gateway through which the specified subnet is to communicate with the network.  # noqa: E501

        :param gateway: The gateway of this Subnet.  # noqa: E501
        :type: str
        """

        self._gateway = gateway

    @property
    def interfaces(self):
        """Gets the interfaces of this Subnet.  # noqa: E501

        List of network interfaces associated with this subnet.  # noqa: E501

        :return: The interfaces of this Subnet.  # noqa: E501
        :rtype: list[Reference]
        """
        return self._interfaces

    @interfaces.setter
    def interfaces(self, interfaces):
        """Sets the interfaces of this Subnet.

        List of network interfaces associated with this subnet.  # noqa: E501

        :param interfaces: The interfaces of this Subnet.  # noqa: E501
        :type: list[Reference]
        """

        self._interfaces = interfaces

    @property
    def link_aggregation_group(self):
        """Gets the link_aggregation_group of this Subnet.  # noqa: E501

        reference of the associated LAG.  # noqa: E501

        :return: The link_aggregation_group of this Subnet.  # noqa: E501
        :rtype: Reference
        """
        return self._link_aggregation_group

    @link_aggregation_group.setter
    def link_aggregation_group(self, link_aggregation_group):
        """Sets the link_aggregation_group of this Subnet.

        reference of the associated LAG.  # noqa: E501

        :param link_aggregation_group: The link_aggregation_group of this Subnet.  # noqa: E501
        :type: Reference
        """

        self._link_aggregation_group = link_aggregation_group

    @property
    def mtu(self):
        """Gets the mtu of this Subnet.  # noqa: E501

        Maximum message transfer unit (packet) size for the subnet in bytes. MTU setting cannot exceed the MTU of the corresponding physical interface. 1500 by default.  # noqa: E501

        :return: The mtu of this Subnet.  # noqa: E501
        :rtype: int
        """
        return self._mtu

    @mtu.setter
    def mtu(self, mtu):
        """Sets the mtu of this Subnet.

        Maximum message transfer unit (packet) size for the subnet in bytes. MTU setting cannot exceed the MTU of the corresponding physical interface. 1500 by default.  # noqa: E501

        :param mtu: The mtu of this Subnet.  # noqa: E501
        :type: int
        """
        if mtu is not None and mtu > 9216:  # noqa: E501
            raise ValueError("Invalid value for `mtu`, must be a value less than or equal to `9216`")  # noqa: E501
        if mtu is not None and mtu < 1280:  # noqa: E501
            raise ValueError("Invalid value for `mtu`, must be a value greater than or equal to `1280`")  # noqa: E501

        self._mtu = mtu

    @property
    def prefix(self):
        """Gets the prefix of this Subnet.  # noqa: E501

        The IPv4 or IPv6 address to be associated with the specified subnet.  # noqa: E501

        :return: The prefix of this Subnet.  # noqa: E501
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """Sets the prefix of this Subnet.

        The IPv4 or IPv6 address to be associated with the specified subnet.  # noqa: E501

        :param prefix: The prefix of this Subnet.  # noqa: E501
        :type: str
        """

        self._prefix = prefix

    @property
    def services(self):
        """Gets the services of this Subnet.  # noqa: E501

        The services provided by this subnet, as inherited from all of its interfaces  # noqa: E501

        :return: The services of this Subnet.  # noqa: E501
        :rtype: list[str]
        """
        return self._services

    @services.setter
    def services(self, services):
        """Sets the services of this Subnet.

        The services provided by this subnet, as inherited from all of its interfaces  # noqa: E501

        :param services: The services of this Subnet.  # noqa: E501
        :type: list[str]
        """

        self._services = services

    @property
    def vlan(self):
        """Gets the vlan of this Subnet.  # noqa: E501

        VLAN ID  # noqa: E501

        :return: The vlan of this Subnet.  # noqa: E501
        :rtype: int
        """
        return self._vlan

    @vlan.setter
    def vlan(self, vlan):
        """Sets the vlan of this Subnet.

        VLAN ID  # noqa: E501

        :param vlan: The vlan of this Subnet.  # noqa: E501
        :type: int
        """

        self._vlan = vlan

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Subnet, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Subnet):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# import apis into api package
from .authentication_api import AuthenticationApi
from .file_system_snapshots_api import FileSystemSnapshotsApi
from .file_systems_api import FileSystemsApi
from .version_api import VersionApi



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.11 Python SDK

    Pure Storage FlashBlade REST 1.11 Python SDK. Compatible with REST API versions 1.0 - 1.11. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.11
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SnmpManagerPost(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'host': 'str',
        'notification': 'str',
        'version': 'str',
        'v2c': 'SnmpV2c',
        'v3': 'SnmpV3'
    }

    attribute_map = {
        'host': 'host',
        'notification': 'notification',
        'version': 'version',
        'v2c': 'v2c',
        'v3': 'v3'
    }

    def __init__(self, host=None, notification=None, version=None, v2c=None, v3=None):  # noqa: E501
        """SnmpManagerPost - a model defined in Swagger"""  # noqa: E501

        self._host = None
        self._notification = None
        self._version = None
        self._v2c = None
        self._v3 = None
        self.discriminator = None

        if host is not None:
            self.host = host
        if notification is not None:
            self.notification = notification
        if version is not None:
            self.version = version
        if v2c is not None:
            self.v2c = v2c
        if v3 is not None:
            self.v3 = v3

    @property
    def host(self):
        """Gets the host of this SnmpManagerPost.  # noqa: E501

        DNS hostname or IP address of a computer that hosts an SNMP manager to which Purity is to send trap messages when it generates alerts.  # noqa: E501

        :return: The host of this SnmpManagerPost.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this SnmpManagerPost.

        DNS hostname or IP address of a computer that hosts an SNMP manager to which Purity is to send trap messages when it generates alerts.  # noqa: E501

        :param host: The host of this SnmpManagerPost.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def notification(self):
        """Gets the notification of this SnmpManagerPost.  # noqa: E501

        The type of notification the agent will send. Valid values are `inform` and `trap`.  # noqa: E501

        :return: The notification of this SnmpManagerPost.  # noqa: E501
        :rtype: str
        """
        return self._notification

    @notification.setter
    def notification(self, notification):
        """Sets the notification of this SnmpManagerPost.

        The type of notification the agent will send. Valid values are `inform` and `trap`.  # noqa: E501

        :param notification: The notification of this SnmpManagerPost.  # noqa: E501
        :type: str
        """

        self._notification = notification

    @property
    def version(self):
        """Gets the version of this SnmpManagerPost.  # noqa: E501

        Version of the SNMP protocol to be used by Purity in communications with the specified manager. Valid values are `v2c` and `v3`.  # noqa: E501

        :return: The version of this SnmpManagerPost.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SnmpManagerPost.

        Version of the SNMP protocol to be used by Purity in communications with the specified manager. Valid values are `v2c` and `v3`.  # noqa: E501

        :param version: The version of this SnmpManagerPost.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def v2c(self):
        """Gets the v2c of this SnmpManagerPost.  # noqa: E501


        :return: The v2c of this SnmpManagerPost.  # noqa: E501
        :rtype: SnmpV2c
        """
        return self._v2c

    @v2c.setter
    def v2c(self, v2c):
        """Sets the v2c of this SnmpManagerPost.


        :param v2c: The v2c of this SnmpManagerPost.  # noqa: E501
        :type: SnmpV2c
        """

        self._v2c = v2c

    @property
    def v3(self):
        """Gets the v3 of this SnmpManagerPost.  # noqa: E501


        :return: The v3 of this SnmpManagerPost.  # noqa: E501
        :rtype: SnmpV3
        """
        return self._v3

    @v3.setter
    def v3(self, v3):
        """Sets the v3 of this SnmpManagerPost.


        :param v3: The v3 of this SnmpManagerPost.  # noqa: E501
        :type: SnmpV3
        """

        self._v3 = v3

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SnmpManagerPost, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SnmpManagerPost):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.12 Python SDK

    Pure Storage FlashBlade REST 1.12 Python SDK. Compatible with REST API versions 1.0 - 1.12. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.12
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import sys
from setuptools import setup, find_packages

NAME = "Pure Storage FlashBlade REST 1.12 Python SDK Documentation"
VERSION = "1.12.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Pure Storage FlashBlade REST 1.12 Python SDK",
    author_email="info@purestorage.com",
    url="",
    keywords=["Swagger", "Pure Storage FlashBlade REST 1.12 Python SDK"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    Pure Storage FlashBlade REST 1.12 Python SDK. Compatible with REST API versions 1.0 - 1.12. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).
    """
)



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.6 Python SDK

    Pure Storage FlashBlade REST 1.6 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.6
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Support(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'created': 'int',
        'phonehome_enabled': 'bool',
        'proxy': 'str',
        'remote_assist_active': 'bool',
        'remote_assist_opened': 'str',
        'remote_assist_expires': 'str',
        'remote_assist_status': 'str',
        'remote_assist_paths': 'list[SupportRemoteAssistPaths]'
    }

    attribute_map = {
        'name': 'name',
        'created': 'created',
        'phonehome_enabled': 'phonehome_enabled',
        'proxy': 'proxy',
        'remote_assist_active': 'remote_assist_active',
        'remote_assist_opened': 'remote_assist_opened',
        'remote_assist_expires': 'remote_assist_expires',
        'remote_assist_status': 'remote_assist_status',
        'remote_assist_paths': 'remote_assist_paths'
    }

    def __init__(self, name=None, created=None, phonehome_enabled=None, proxy=None, remote_assist_active=None, remote_assist_opened=None, remote_assist_expires=None, remote_assist_status=None, remote_assist_paths=None):  # noqa: E501
        """Support - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._created = None
        self._phonehome_enabled = None
        self._proxy = None
        self._remote_assist_active = None
        self._remote_assist_opened = None
        self._remote_assist_expires = None
        self._remote_assist_status = None
        self._remote_assist_paths = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if created is not None:
            self.created = created
        if phonehome_enabled is not None:
            self.phonehome_enabled = phonehome_enabled
        if proxy is not None:
            self.proxy = proxy
        if remote_assist_active is not None:
            self.remote_assist_active = remote_assist_active
        if remote_assist_opened is not None:
            self.remote_assist_opened = remote_assist_opened
        if remote_assist_expires is not None:
            self.remote_assist_expires = remote_assist_expires
        if remote_assist_status is not None:
            self.remote_assist_status = remote_assist_status
        if remote_assist_paths is not None:
            self.remote_assist_paths = remote_assist_paths

    @property
    def name(self):
        """Gets the name of this Support.  # noqa: E501

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :return: The name of this Support.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Support.

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :param name: The name of this Support.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def created(self):
        """Gets the created of this Support.  # noqa: E501

        Creation timestamp of the object  # noqa: E501

        :return: The created of this Support.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Support.

        Creation timestamp of the object  # noqa: E501

        :param created: The created of this Support.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def phonehome_enabled(self):
        """Gets the phonehome_enabled of this Support.  # noqa: E501

        Is phonehome of logs enabled?  # noqa: E501

        :return: The phonehome_enabled of this Support.  # noqa: E501
        :rtype: bool
        """
        return self._phonehome_enabled

    @phonehome_enabled.setter
    def phonehome_enabled(self, phonehome_enabled):
        """Sets the phonehome_enabled of this Support.

        Is phonehome of logs enabled?  # noqa: E501

        :param phonehome_enabled: The phonehome_enabled of this Support.  # noqa: E501
        :type: bool
        """

        self._phonehome_enabled = phonehome_enabled

    @property
    def proxy(self):
        """Gets the proxy of this Support.  # noqa: E501

        Server to use as the HTTP or HTTPS proxy. Specify the server name, including the scheme and proxy port number.  # noqa: E501

        :return: The proxy of this Support.  # noqa: E501
        :rtype: str
        """
        return self._proxy

    @proxy.setter
    def proxy(self, proxy):
        """Sets the proxy of this Support.

        Server to use as the HTTP or HTTPS proxy. Specify the server name, including the scheme and proxy port number.  # noqa: E501

        :param proxy: The proxy of this Support.  # noqa: E501
        :type: str
        """

        self._proxy = proxy

    @property
    def remote_assist_active(self):
        """Gets the remote_assist_active of this Support.  # noqa: E501

        The switch to open all remote-assist sessions. Modifiable.  # noqa: E501

        :return: The remote_assist_active of this Support.  # noqa: E501
        :rtype: bool
        """
        return self._remote_assist_active

    @remote_assist_active.setter
    def remote_assist_active(self, remote_assist_active):
        """Sets the remote_assist_active of this Support.

        The switch to open all remote-assist sessions. Modifiable.  # noqa: E501

        :param remote_assist_active: The remote_assist_active of this Support.  # noqa: E501
        :type: bool
        """

        self._remote_assist_active = remote_assist_active

    @property
    def remote_assist_opened(self):
        """Gets the remote_assist_opened of this Support.  # noqa: E501

        The time when the session opened.  # noqa: E501

        :return: The remote_assist_opened of this Support.  # noqa: E501
        :rtype: str
        """
        return self._remote_assist_opened

    @remote_assist_opened.setter
    def remote_assist_opened(self, remote_assist_opened):
        """Sets the remote_assist_opened of this Support.

        The time when the session opened.  # noqa: E501

        :param remote_assist_opened: The remote_assist_opened of this Support.  # noqa: E501
        :type: str
        """

        self._remote_assist_opened = remote_assist_opened

    @property
    def remote_assist_expires(self):
        """Gets the remote_assist_expires of this Support.  # noqa: E501

        The time when the session expires.  # noqa: E501

        :return: The remote_assist_expires of this Support.  # noqa: E501
        :rtype: str
        """
        return self._remote_assist_expires

    @remote_assist_expires.setter
    def remote_assist_expires(self, remote_assist_expires):
        """Sets the remote_assist_expires of this Support.

        The time when the session expires.  # noqa: E501

        :param remote_assist_expires: The remote_assist_expires of this Support.  # noqa: E501
        :type: str
        """

        self._remote_assist_expires = remote_assist_expires

    @property
    def remote_assist_status(self):
        """Gets the remote_assist_status of this Support.  # noqa: E501

        The status of the remote-assist sessions. Possible values are connected, partially_connected, reconnecting, and disconnected.  # noqa: E501

        :return: The remote_assist_status of this Support.  # noqa: E501
        :rtype: str
        """
        return self._remote_assist_status

    @remote_assist_status.setter
    def remote_assist_status(self, remote_assist_status):
        """Sets the remote_assist_status of this Support.

        The status of the remote-assist sessions. Possible values are connected, partially_connected, reconnecting, and disconnected.  # noqa: E501

        :param remote_assist_status: The remote_assist_status of this Support.  # noqa: E501
        :type: str
        """

        self._remote_assist_status = remote_assist_status

    @property
    def remote_assist_paths(self):
        """Gets the remote_assist_paths of this Support.  # noqa: E501


        :return: The remote_assist_paths of this Support.  # noqa: E501
        :rtype: list[SupportRemoteAssistPaths]
        """
        return self._remote_assist_paths

    @remote_assist_paths.setter
    def remote_assist_paths(self, remote_assist_paths):
        """Sets the remote_assist_paths of this Support.


        :param remote_assist_paths: The remote_assist_paths of this Support.  # noqa: E501
        :type: list[SupportRemoteAssistPaths]
        """

        self._remote_assist_paths = remote_assist_paths

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Support, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Support):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.11 Python SDK

    Pure Storage FlashBlade REST 1.11 Python SDK. Compatible with REST API versions 1.0 - 1.11. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.11
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SyslogServerSetting(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'id': 'str',
        'ca_certificate': 'Reference',
        'ca_certificate_group': 'Reference'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'ca_certificate': 'ca_certificate',
        'ca_certificate_group': 'ca_certificate_group'
    }

    def __init__(self, name=None, id=None, ca_certificate=None, ca_certificate_group=None):  # noqa: E501
        """SyslogServerSetting - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._id = None
        self._ca_certificate = None
        self._ca_certificate_group = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if ca_certificate is not None:
            self.ca_certificate = ca_certificate
        if ca_certificate_group is not None:
            self.ca_certificate_group = ca_certificate_group

    @property
    def name(self):
        """Gets the name of this SyslogServerSetting.  # noqa: E501

        The name of the object  # noqa: E501

        :return: The name of this SyslogServerSetting.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SyslogServerSetting.

        The name of the object  # noqa: E501

        :param name: The name of this SyslogServerSetting.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this SyslogServerSetting.  # noqa: E501

        A unique ID chosen by the system. Cannot change.  # noqa: E501

        :return: The id of this SyslogServerSetting.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SyslogServerSetting.

        A unique ID chosen by the system. Cannot change.  # noqa: E501

        :param id: The id of this SyslogServerSetting.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ca_certificate(self):
        """Gets the ca_certificate of this SyslogServerSetting.  # noqa: E501

        CA certificate used to validate the authenticity of the configured servers.  # noqa: E501

        :return: The ca_certificate of this SyslogServerSetting.  # noqa: E501
        :rtype: Reference
        """
        return self._ca_certificate

    @ca_certificate.setter
    def ca_certificate(self, ca_certificate):
        """Sets the ca_certificate of this SyslogServerSetting.

        CA certificate used to validate the authenticity of the configured servers.  # noqa: E501

        :param ca_certificate: The ca_certificate of this SyslogServerSetting.  # noqa: E501
        :type: Reference
        """

        self._ca_certificate = ca_certificate

    @property
    def ca_certificate_group(self):
        """Gets the ca_certificate_group of this SyslogServerSetting.  # noqa: E501

        A certificate group containing CA certificates that can be used to validate the authenticity of the configured servers.  # noqa: E501

        :return: The ca_certificate_group of this SyslogServerSetting.  # noqa: E501
        :rtype: Reference
        """
        return self._ca_certificate_group

    @ca_certificate_group.setter
    def ca_certificate_group(self, ca_certificate_group):
        """Sets the ca_certificate_group of this SyslogServerSetting.

        A certificate group containing CA certificates that can be used to validate the authenticity of the configured servers.  # noqa: E501

        :param ca_certificate_group: The ca_certificate_group of this SyslogServerSetting.  # noqa: E501
        :type: Reference
        """

        self._ca_certificate_group = ca_certificate_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SyslogServerSetting, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyslogServerSetting):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.10 Python SDK

    Pure Storage FlashBlade REST 1.10 Python SDK. Compatible with REST API versions 1.0 - 1.10. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.10
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ReplicaLinkBuiltIn(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'direction': 'Direction',
        'id': 'str',
        'lag': 'int',
        'remote': 'FixedReferenceWithId',
        'status_details': 'str'
    }

    attribute_map = {
        'direction': 'direction',
        'id': 'id',
        'lag': 'lag',
        'remote': 'remote',
        'status_details': 'status_details'
    }

    def __init__(self, direction=None, id=None, lag=None, remote=None, status_details=None):  # noqa: E501
        """ReplicaLinkBuiltIn - a model defined in Swagger"""  # noqa: E501

        self._direction = None
        self._id = None
        self._lag = None
        self._remote = None
        self._status_details = None
        self.discriminator = None

        if direction is not None:
            self.direction = direction
        if id is not None:
            self.id = id
        if lag is not None:
            self.lag = lag
        if remote is not None:
            self.remote = remote
        if status_details is not None:
            self.status_details = status_details

    @property
    def direction(self):
        """Gets the direction of this ReplicaLinkBuiltIn.  # noqa: E501


        :return: The direction of this ReplicaLinkBuiltIn.  # noqa: E501
        :rtype: Direction
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this ReplicaLinkBuiltIn.


        :param direction: The direction of this ReplicaLinkBuiltIn.  # noqa: E501
        :type: Direction
        """

        self._direction = direction

    @property
    def id(self):
        """Gets the id of this ReplicaLinkBuiltIn.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this ReplicaLinkBuiltIn.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ReplicaLinkBuiltIn.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this ReplicaLinkBuiltIn.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def lag(self):
        """Gets the lag of this ReplicaLinkBuiltIn.  # noqa: E501

        Duration in milliseconds that represents how far behind the replication target is from the source. This is the time difference between current time and `recovery_point`.  # noqa: E501

        :return: The lag of this ReplicaLinkBuiltIn.  # noqa: E501
        :rtype: int
        """
        return self._lag

    @lag.setter
    def lag(self, lag):
        """Sets the lag of this ReplicaLinkBuiltIn.

        Duration in milliseconds that represents how far behind the replication target is from the source. This is the time difference between current time and `recovery_point`.  # noqa: E501

        :param lag: The lag of this ReplicaLinkBuiltIn.  # noqa: E501
        :type: int
        """

        self._lag = lag

    @property
    def remote(self):
        """Gets the remote of this ReplicaLinkBuiltIn.  # noqa: E501

        Reference to a remote target.  # noqa: E501

        :return: The remote of this ReplicaLinkBuiltIn.  # noqa: E501
        :rtype: FixedReferenceWithId
        """
        return self._remote

    @remote.setter
    def remote(self, remote):
        """Sets the remote of this ReplicaLinkBuiltIn.

        Reference to a remote target.  # noqa: E501

        :param remote: The remote of this ReplicaLinkBuiltIn.  # noqa: E501
        :type: FixedReferenceWithId
        """

        self._remote = remote

    @property
    def status_details(self):
        """Gets the status_details of this ReplicaLinkBuiltIn.  # noqa: E501

        Detailed information about the status of the replica link.  # noqa: E501

        :return: The status_details of this ReplicaLinkBuiltIn.  # noqa: E501
        :rtype: str
        """
        return self._status_details

    @status_details.setter
    def status_details(self, status_details):
        """Sets the status_details of this ReplicaLinkBuiltIn.

        Detailed information about the status of the replica link.  # noqa: E501

        :param status_details: The status_details of this ReplicaLinkBuiltIn.  # noqa: E501
        :type: str
        """

        self._status_details = status_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReplicaLinkBuiltIn, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReplicaLinkBuiltIn):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.11 Python SDK

    Pure Storage FlashBlade REST 1.11 Python SDK. Compatible with REST API versions 1.0 - 1.11. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.11
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class FileSystemsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def create_file_systems(self, file_system, **kwargs):
        """
        Create a new file system.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_file_systems(file_system, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param FileSystem file_system: The attribute map used to create the file system. (required)
        :param bool overwrite: Should we overwrites an existing file system? True if so.
        :param bool discard_non_snapshotted_data: discard (true) the non-snapshotted data.
        :return: FileSystemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_file_systems_with_http_info(file_system, **kwargs)
        else:
            (data) = self.create_file_systems_with_http_info(file_system, **kwargs)
            return data

    def create_file_systems_with_http_info(self, file_system, **kwargs):
        """
        Create a new file system.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_file_systems_with_http_info(file_system, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param FileSystem file_system: The attribute map used to create the file system. (required)
        :param bool overwrite: Should we overwrites an existing file system? True if so.
        :param bool discard_non_snapshotted_data: discard (true) the non-snapshotted data.
        :return: FileSystemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_system', 'overwrite', 'discard_non_snapshotted_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_file_systems" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_system' is set
        if ('file_system' not in params) or (params['file_system'] is None):
            raise ValueError("Missing the required parameter `file_system` when calling `create_file_systems`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'overwrite' in params:
            query_params.append(('overwrite', params['overwrite']))
        if 'discard_non_snapshotted_data' in params:
            query_params.append(('discard_non_snapshotted_data', params['discard_non_snapshotted_data']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'file_system' in params:
            body_params = params['file_system']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.11/file-systems', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FileSystemResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_filesystem_policies(self, **kwargs):
        """
        Create a connection between a file system and a policy.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_filesystem_policies(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] policy_ids: A comma-separated list of policy IDs. This cannot be provided together with the policy names query parameters.
        :param list[str] policy_names: A comma-separated list of policy names. This cannot be provided together with the policy ids query parameters.
        :param list[str] member_ids: A comma-separated list of member ids. This cannot be provided together with the member names query parameters.
        :param list[str] member_names: A comma-separated list of member names. This cannot be provided together with the member ids query parameters.
        :return: PolicyMemberResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_filesystem_policies_with_http_info(**kwargs)
        else:
            (data) = self.create_filesystem_policies_with_http_info(**kwargs)
            return data

    def create_filesystem_policies_with_http_info(self, **kwargs):
        """
        Create a connection between a file system and a policy.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_filesystem_policies_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] policy_ids: A comma-separated list of policy IDs. This cannot be provided together with the policy names query parameters.
        :param list[str] policy_names: A comma-separated list of policy names. This cannot be provided together with the policy ids query parameters.
        :param list[str] member_ids: A comma-separated list of member ids. This cannot be provided together with the member names query parameters.
        :param list[str] member_names: A comma-separated list of member names. This cannot be provided together with the member ids query parameters.
        :return: PolicyMemberResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['policy_ids', 'policy_names', 'member_ids', 'member_names']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_filesystem_policies" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'policy_ids' in params:
            query_params.append(('policy_ids', params['policy_ids']))
            collection_formats['policy_ids'] = 'csv'
        if 'policy_names' in params:
            query_params.append(('policy_names', params['policy_names']))
            collection_formats['policy_names'] = 'csv'
        if 'member_ids' in params:
            query_params.append(('member_ids', params['member_ids']))
            collection_formats['member_ids'] = 'csv'
        if 'member_names' in params:
            query_params.append(('member_names', params['member_names']))
            collection_formats['member_names'] = 'csv'

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.11/file-systems/policies', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='PolicyMemberResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def delete_file_systems(self, **kwargs):
        """
        Delete a file system.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_file_systems(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] ids: A comma-separated list of resource IDs. This cannot be provided together with the name or names query parameters.
        :param str name: The name of the file system or snapshot to be updated.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_file_systems_with_http_info(**kwargs)
        else:
            (data) = self.delete_file_systems_with_http_info(**kwargs)
            return data

    def delete_file_systems_with_http_info(self, **kwargs):
        """
        Delete a file system.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_file_systems_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] ids: A comma-separated list of resource IDs. This cannot be provided together with the name or names query parameters.
        :param str name: The name of the file system or snapshot to be updated.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ids', 'name']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_file_systems" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'ids' in params:
            query_params.append(('ids', params['ids']))
            collection_formats['ids'] = 'csv'
        if 'name' in params:
            query_params.append(('name', params['name']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.11/file-systems', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def delete_filesystem_policies(self, **kwargs):
        """
        Delete a connection between a file system and a policy.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_filesystem_policies(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] policy_ids: A comma-separated list of policy IDs. This cannot be provided together with the policy names query parameters.
        :param list[str] policy_names: A comma-separated list of policy names. This cannot be provided together with the policy ids query parameters.
        :param list[str] member_ids: A comma-separated list of member ids. This cannot be provided together with the member names query parameters.
        :param list[str] member_names: A comma-separated list of member names. This cannot be provided together with the member ids query parameters.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_filesystem_policies_with_http_info(**kwargs)
        else:
            (data) = self.delete_filesystem_policies_with_http_info(**kwargs)
            return data

    def delete_filesystem_policies_with_http_info(self, **kwargs):
        """
        Delete a connection between a file system and a policy.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_filesystem_policies_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] policy_ids: A comma-separated list of policy IDs. This cannot be provided together with the policy names query parameters.
        :param list[str] policy_names: A comma-separated list of policy names. This cannot be provided together with the policy ids query parameters.
        :param list[str] member_ids: A comma-separated list of member ids. This cannot be provided together with the member names query parameters.
        :param list[str] member_names: A comma-separated list of member names. This cannot be provided together with the member ids query parameters.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['policy_ids', 'policy_names', 'member_ids', 'member_names']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_filesystem_policies" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'policy_ids' in params:
            query_params.append(('policy_ids', params['policy_ids']))
            collection_formats['policy_ids'] = 'csv'
        if 'policy_names' in params:
            query_params.append(('policy_names', params['policy_names']))
            collection_formats['policy_names'] = 'csv'
        if 'member_ids' in params:
            query_params.append(('member_ids', params['member_ids']))
            collection_formats['member_ids'] = 'csv'
        if 'member_names' in params:
            query_params.append(('member_names', params['member_names']))
            collection_formats['member_names'] = 'csv'

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.11/file-systems/policies', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def list_file_systems(self, **kwargs):
        """
        List file systems.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_file_systems(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] ids: A comma-separated list of resource IDs. This cannot be provided together with the name or names query parameters.
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :param str filter: The filter to be used for query.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start: The offset of the first resource to return from a collection.
        :param int limit: limit, should be >= 0
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :param bool total_only: Return only the total object.
        :return: FileSystemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_file_systems_with_http_info(**kwargs)
        else:
            (data) = self.list_file_systems_with_http_info(**kwargs)
            return data

    def list_file_systems_with_http_info(self, **kwargs):
        """
        List file systems.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_file_systems_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] ids: A comma-separated list of resource IDs. This cannot be provided together with the name or names query parameters.
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :param str filter: The filter to be used for query.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start: The offset of the first resource to return from a collection.
        :param int limit: limit, should be >= 0
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :param bool total_only: Return only the total object.
        :return: FileSystemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ids', 'names', 'filter', 'sort', 'start', 'limit', 'token', 'total_only']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_file_systems" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'ids' in params:
            query_params.append(('ids', params['ids']))
            collection_formats['ids'] = 'csv'
        if 'names' in params:
            query_params.append(('names', params['names']))
            collection_formats['names'] = 'csv'
        if 'filter' in params:
            query_params.append(('filter', params['filter']))
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'start' in params:
            query_params.append(('start', params['start']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'token' in params:
            query_params.append(('token', params['token']))
        if 'total_only' in params:
            query_params.append(('total_only', params['total_only']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.11/file-systems', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FileSystemResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def list_file_systems_performance(self, **kwargs):
        """
        List instant or historical file system performance.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_file_systems_performance(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int resolution: sample frequency in milliseconds
        :param str protocol: to sample performance of a certain protocol
        :param int end_time: Time to end sample in milliseconds since epoch.
        :param str filter: The filter to be used for query.
        :param list[str] ids: A comma-separated list of resource IDs. This cannot be provided together with the name or names query parameters.
        :param int limit: limit, should be >= 0
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start_time: Time to start sample in milliseconds since epoch.
        :param int start: The offset of the first resource to return from a collection.
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :param bool total_only: Return only the total object.
        :return: FileSystemPerformanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_file_systems_performance_with_http_info(**kwargs)
        else:
            (data) = self.list_file_systems_performance_with_http_info(**kwargs)
            return data

    def list_file_systems_performance_with_http_info(self, **kwargs):
        """
        List instant or historical file system performance.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_file_systems_performance_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int resolution: sample frequency in milliseconds
        :param str protocol: to sample performance of a certain protocol
        :param int end_time: Time to end sample in milliseconds since epoch.
        :param str filter: The filter to be used for query.
        :param list[str] ids: A comma-separated list of resource IDs. This cannot be provided together with the name or names query parameters.
        :param int limit: limit, should be >= 0
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start_time: Time to start sample in milliseconds since epoch.
        :param int start: The offset of the first resource to return from a collection.
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :param bool total_only: Return only the total object.
        :return: FileSystemPerformanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['resolution', 'protocol', 'end_time', 'filter', 'ids', 'limit', 'names', 'sort', 'start_time', 'start', 'token', 'total_only']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_file_systems_performance" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'resolution' in params:
            query_params.append(('resolution', params['resolution']))
        if 'protocol' in params:
            query_params.append(('protocol', params['protocol']))
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))
        if 'filter' in params:
            query_params.append(('filter', params['filter']))
        if 'ids' in params:
            query_params.append(('ids', params['ids']))
            collection_formats['ids'] = 'csv'
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'names' in params:
            query_params.append(('names', params['names']))
            collection_formats['names'] = 'csv'
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))
        if 'start' in params:
            query_params.append(('start', params['start']))
        if 'token' in params:
            query_params.append(('token', params['token']))
        if 'total_only' in params:
            query_params.append(('total_only', params['total_only']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.11/file-systems/performance', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FileSystemPerformanceResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def list_filesystem_policies(self, **kwargs):
        """
        List policies attached to filesystems.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_filesystem_policies(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] policy_ids: A comma-separated list of policy IDs. This cannot be provided together with the policy names query parameters.
        :param list[str] policy_names: A comma-separated list of policy names. This cannot be provided together with the policy ids query parameters.
        :param list[str] member_ids: A comma-separated list of member ids. This cannot be provided together with the member names query parameters.
        :param list[str] member_names: A comma-separated list of member names. This cannot be provided together with the member ids query parameters.
        :param str filter: The filter to be used for query.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start: The offset of the first resource to return from a collection.
        :param int limit: limit, should be >= 0
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :return: PolicyMemberResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_filesystem_policies_with_http_info(**kwargs)
        else:
            (data) = self.list_filesystem_policies_with_http_info(**kwargs)
            return data

    def list_filesystem_policies_with_http_info(self, **kwargs):
        """
        List policies attached to filesystems.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_filesystem_policies_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] policy_ids: A comma-separated list of policy IDs. This cannot be provided together with the policy names query parameters.
        :param list[str] policy_names: A comma-separated list of policy names. This cannot be provided together with the policy ids query parameters.
        :param list[str] member_ids: A comma-separated list of member ids. This cannot be provided together with the member names query parameters.
        :param list[str] member_names: A comma-separated list of member names. This cannot be provided together with the member ids query parameters.
        :param str filter: The filter to be used for query.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start: The offset of the first resource to return from a collection.
        :param int limit: limit, should be >= 0
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :return: PolicyMemberResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['policy_ids', 'policy_names', 'member_ids', 'member_names', 'filter', 'sort', 'start', 'limit', 'token']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_filesystem_policies" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'policy_ids' in params:
            query_params.append(('policy_ids', params['policy_ids']))
            collection_formats['policy_ids'] = 'csv'
        if 'policy_names' in params:
            query_params.append(('policy_names', params['policy_names']))
            collection_formats['policy_names'] = 'csv'
        if 'member_ids' in params:
            query_params.append(('member_ids', params['member_ids']))
            collection_formats['member_ids'] = 'csv'
        if 'member_names' in params:
            query_params.append(('member_names', params['member_names']))
            collection_formats['member_names'] = 'csv'
        if 'filter' in params:
            query_params.append(('filter', params['filter']))
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'start' in params:
            query_params.append(('start', params['start']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'token' in params:
            query_params.append(('token', params['token']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.11/file-systems/policies', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='PolicyMemberResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_file_systems(self, attributes, **kwargs):
        """
        Update an existing file system.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_file_systems(attributes, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param FileSystemPatch attributes: The new attributes, only modifiable fields may be specified. (required)
        :param list[str] ids: A comma-separated list of resource IDs. This cannot be provided together with the name or names query parameters.
        :param str name: The name of the file system or snapshot to be updated.
        :param bool discard_detailed_permissions: This parameter must be set to `true` in order to change a file system's `access_control_style` from a style that supports more detailed access control lists to a style that only supports less detailed mode bits as a form of permission control. This parameter may not be set to `true` any other time. Setting this parameter to `true` is acknowledgement that any more detailed access control lists currently set within the file system will be lost, and NFS permission controls will only be enforced at the granularity level of NFS mode bits.
        :param bool discard_non_snapshotted_data: This parameter must be set to `true` in order to restore a file system from a snapshot or to demote a file system (which restores the file system from the common baseline snapshot). Setting this parameter to `true` is acknowledgement that any non-snapshotted data currently in the file system will be irretrievably lost.
        :param bool delete_link_on_eradication: If set to `true`, the file system can be destroyed, even if it has a replica link. If set to `false`, the file system cannot be destroyed if it has a replica link. Defaults to `false`.
        :param bool ignore_usage: Allow update operations that lead to a hard_limit_enabled file system with usage over its provisioned size. The update can be either setting hard_limit_enabled when usage is higher than provisioned size, or resize provisioned size to a value under usage when hard_limit_enabled is True.
        :return: FileSystemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_file_systems_with_http_info(attributes, **kwargs)
        else:
            (data) = self.update_file_systems_with_http_info(attributes, **kwargs)
            return data

    def update_file_systems_with_http_info(self, attributes, **kwargs):
        """
        Update an existing file system.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_file_systems_with_http_info(attributes, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param FileSystemPatch attributes: The new attributes, only modifiable fields may be specified. (required)
        :param list[str] ids: A comma-separated list of resource IDs. This cannot be provided together with the name or names query parameters.
        :param str name: The name of the file system or snapshot to be updated.
        :param bool discard_detailed_permissions: This parameter must be set to `true` in order to change a file system's `access_control_style` from a style that supports more detailed access control lists to a style that only supports less detailed mode bits as a form of permission control. This parameter may not be set to `true` any other time. Setting this parameter to `true` is acknowledgement that any more detailed access control lists currently set within the file system will be lost, and NFS permission controls will only be enforced at the granularity level of NFS mode bits.
        :param bool discard_non_snapshotted_data: This parameter must be set to `true` in order to restore a file system from a snapshot or to demote a file system (which restores the file system from the common baseline snapshot). Setting this parameter to `true` is acknowledgement that any non-snapshotted data currently in the file system will be irretrievably lost.
        :param bool delete_link_on_eradication: If set to `true`, the file system can be destroyed, even if it has a replica link. If set to `false`, the file system cannot be destroyed if it has a replica link. Defaults to `false`.
        :param bool ignore_usage: Allow update operations that lead to a hard_limit_enabled file system with usage over its provisioned size. The update can be either setting hard_limit_enabled when usage is higher than provisioned size, or resize provisioned size to a value under usage when hard_limit_enabled is True.
        :return: FileSystemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['attributes', 'ids', 'name', 'discard_detailed_permissions', 'discard_non_snapshotted_data', 'delete_link_on_eradication', 'ignore_usage']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_file_systems" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'attributes' is set
        if ('attributes' not in params) or (params['attributes'] is None):
            raise ValueError("Missing the required parameter `attributes` when calling `update_file_systems`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'ids' in params:
            query_params.append(('ids', params['ids']))
            collection_formats['ids'] = 'csv'
        if 'name' in params:
            query_params.append(('name', params['name']))
        if 'discard_detailed_permissions' in params:
            query_params.append(('discard_detailed_permissions', params['discard_detailed_permissions']))
        if 'discard_non_snapshotted_data' in params:
            query_params.append(('discard_non_snapshotted_data', params['discard_non_snapshotted_data']))
        if 'delete_link_on_eradication' in params:
            query_params.append(('delete_link_on_eradication', params['delete_link_on_eradication']))
        if 'ignore_usage' in params:
            query_params.append(('ignore_usage', params['ignore_usage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'attributes' in params:
            body_params = params['attributes']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.11/file-systems', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FileSystemResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.8 Python SDK

    Pure Storage FlashBlade REST 1.8 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.8
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.admin import Admin
from .models.admin_api_token import AdminApiToken
from .models.admin_cache import AdminCache
from .models.admin_cache_response import AdminCacheResponse
from .models.admin_response import AdminResponse
from .models.alert import Alert
from .models.alert_response import AlertResponse
from .models.alert_watcher import AlertWatcher
from .models.alert_watcher_response import AlertWatcherResponse
from .models.alert_watcher_test import AlertWatcherTest
from .models.alert_watcher_test_response import AlertWatcherTestResponse
from .models.array_http_performance import ArrayHttpPerformance
from .models.array_http_performance_response import ArrayHttpPerformanceResponse
from .models.array_performance import ArrayPerformance
from .models.array_performance_response import ArrayPerformanceResponse
from .models.array_response import ArrayResponse
from .models.array_s3_performance import ArrayS3Performance
from .models.array_s3_performance_response import ArrayS3PerformanceResponse
from .models.array_space import ArraySpace
from .models.array_space_response import ArraySpaceResponse
from .models.blade import Blade
from .models.blade_response import BladeResponse
from .models.bucket import Bucket
from .models.bucket_patch import BucketPatch
from .models.bucket_performance import BucketPerformance
from .models.bucket_performance_response import BucketPerformanceResponse
from .models.bucket_post import BucketPost
from .models.bucket_response import BucketResponse
from .models.bucket_s3_performance import BucketS3Performance
from .models.bucket_s3_performance_response import BucketS3PerformanceResponse
from .models._built_in import BuiltIn
from .models._built_in_with_id import BuiltInWithId
from .models.certificate import Certificate
from .models.certificate_group import CertificateGroup
from .models.certificate_group_response import CertificateGroupResponse
from .models.certificate_group_use import CertificateGroupUse
from .models.certificate_group_use_response import CertificateGroupUseResponse
from .models.certificate_post import CertificatePost
from .models.certificate_response import CertificateResponse
from .models.certificate_use import CertificateUse
from .models.certificate_use_response import CertificateUseResponse
from .models.client_performance import ClientPerformance
from .models.client_performance_response import ClientPerformanceResponse
from .models.directory_service import DirectoryService
from .models.directory_service_response import DirectoryServiceResponse
from .models.directory_service_role import DirectoryServiceRole
from .models.directory_service_roles_response import DirectoryServiceRolesResponse
from .models.directoryservice_nfs import DirectoryserviceNfs
from .models.directoryservice_smb import DirectoryserviceSmb
from .models.dns import Dns
from .models.dns_response import DnsResponse
from .models.error_response import ErrorResponse
from .models.file_system import FileSystem
from .models.file_system_performance import FileSystemPerformance
from .models.file_system_performance_response import FileSystemPerformanceResponse
from .models.file_system_response import FileSystemResponse
from .models.file_system_snapshot import FileSystemSnapshot
from .models.file_system_snapshot_response import FileSystemSnapshotResponse
from .models._fixed_reference import FixedReference
from .models._fixed_reference_with_id import FixedReferenceWithId
from .models.hardware import Hardware
from .models.hardware_connector import HardwareConnector
from .models.hardware_connector_response import HardwareConnectorResponse
from .models.hardware_response import HardwareResponse
from .models.link_aggregation_group import LinkAggregationGroup
from .models.link_aggregation_group_patch import LinkAggregationGroupPatch
from .models.link_aggregation_group_response import LinkAggregationGroupResponse
from .models.log_download_response import LogDownloadResponse
from .models.login_response import LoginResponse
from .models.member import Member
from .models.member_response import MemberResponse
from .models.network_interface import NetworkInterface
from .models.network_interface_response import NetworkInterfaceResponse
from .models.nfs_rule import NfsRule
from .models.object_response import ObjectResponse
from .models.object_store_access_key import ObjectStoreAccessKey
from .models.object_store_access_key_response import ObjectStoreAccessKeyResponse
from .models.object_store_account import ObjectStoreAccount
from .models.object_store_account_response import ObjectStoreAccountResponse
from .models.object_store_user import ObjectStoreUser
from .models.object_store_user_response import ObjectStoreUserResponse
from .models.objectstoreaccesskey import Objectstoreaccesskey
from .models.pagination_info import PaginationInfo
from .models.policy import Policy
from .models.policy_objects import PolicyObjects
from .models.policy_objects_response import PolicyObjectsResponse
from .models.policy_patch import PolicyPatch
from .models._policy_reference_with_id import PolicyReferenceWithId
from .models.policy_response import PolicyResponse
from .models.protocol_rule import ProtocolRule
from .models.pure_array import PureArray
from .models.pure_error import PureError
from .models.pure_object import PureObject
from .models.quotas_group import QuotasGroup
from .models.quotas_group_response import QuotasGroupResponse
from .models.quotas_setting import QuotasSetting
from .models.quotas_setting_response import QuotasSettingResponse
from .models.quotas_user import QuotasUser
from .models.quotas_user_response import QuotasUserResponse
from .models.quotasgroup_group import QuotasgroupGroup
from .models.quotasuser_user import QuotasuserUser
from .models.reference import Reference
from .models._resource import Resource
from .models._resource_rule import ResourceRule
from .models._resource_type import ResourceType
from .models.smb_rule import SmbRule
from .models.smtp import Smtp
from .models.smtp_response import SmtpResponse
from .models.snapshot_suffix import SnapshotSuffix
from .models.space import Space
from .models.subnet import Subnet
from .models.subnet_response import SubnetResponse
from .models.support import Support
from .models.support_remote_assist_paths import SupportRemoteAssistPaths
from .models.support_response import SupportResponse
from .models.test_result import TestResult
from .models.test_result_response import TestResultResponse
from .models.version_response import VersionResponse

# import apis into sdk package
from .apis.admins_api import AdminsApi
from .apis.admins_cache_api import AdminsCacheApi
from .apis.alert_watchers_api import AlertWatchersApi
from .apis.alerts_api import AlertsApi
from .apis.arrays_api import ArraysApi
from .apis.authentication_api import AuthenticationApi
from .apis.blade_api import BladeApi
from .apis.buckets_api import BucketsApi
from .apis.certificate_groups_api import CertificateGroupsApi
from .apis.certificates_api import CertificatesApi
from .apis.directory_services_api import DirectoryServicesApi
from .apis.dns_api import DnsApi
from .apis.file_system_snapshots_api import FileSystemSnapshotsApi
from .apis.file_systems_api import FileSystemsApi
from .apis.hardware_api import HardwareApi
from .apis.hardware_connectors_api import HardwareConnectorsApi
from .apis.link_aggregation_groups_api import LinkAggregationGroupsApi
from .apis.logs_api import LogsApi
from .apis.network_interfaces_api import NetworkInterfacesApi
from .apis.object_store_access_keys_api import ObjectStoreAccessKeysApi
from .apis.object_store_accounts_api import ObjectStoreAccountsApi
from .apis.object_store_users_api import ObjectStoreUsersApi
from .apis.policies_api import PoliciesApi
from .apis.quotas_groups_api import QuotasGroupsApi
from .apis.quotas_settings_api import QuotasSettingsApi
from .apis.quotas_users_api import QuotasUsersApi
from .apis.smtp_api import SmtpApi
from .apis.subnets_api import SubnetsApi
from .apis.support_api import SupportApi
from .apis.usage_groups_api import UsageGroupsApi
from .apis.usage_users_api import UsageUsersApi
from .apis.version_api import VersionApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()



from __future__ import absolute_import

# import apis into api package
from .admins_api import AdminsApi
from .alert_watchers_api import AlertWatchersApi
from .alerts_api import AlertsApi
from .arrays_api import ArraysApi
from .authentication_api import AuthenticationApi
from .blade_api import BladeApi
from .buckets_api import BucketsApi
from .certificates_api import CertificatesApi
from .directory_services_api import DirectoryServicesApi
from .dns_api import DnsApi
from .file_system_snapshots_api import FileSystemSnapshotsApi
from .file_systems_api import FileSystemsApi
from .hardware_api import HardwareApi
from .hardware_connectors_api import HardwareConnectorsApi
from .link_aggregation_groups_api import LinkAggregationGroupsApi
from .network_interfaces_api import NetworkInterfacesApi
from .object_store_access_keys_api import ObjectStoreAccessKeysApi
from .object_store_accounts_api import ObjectStoreAccountsApi
from .object_store_users_api import ObjectStoreUsersApi
from .smtp_api import SmtpApi
from .subnets_api import SubnetsApi
from .version_api import VersionApi



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.4 Python SDK

    Pure Storage FlashBlade REST 1.4 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.4
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .admin import Admin
from .admin_api_token import AdminApiToken
from .admin_cache import AdminCache
from .admin_cache_response import AdminCacheResponse
from .admin_response import AdminResponse
from .alert import Alert
from .alert_response import AlertResponse
from .alert_watcher import AlertWatcher
from .alert_watcher_response import AlertWatcherResponse
from .alert_watcher_test import AlertWatcherTest
from .alert_watcher_test_response import AlertWatcherTestResponse
from .array_http_performance import ArrayHttpPerformance
from .array_http_performance_response import ArrayHttpPerformanceResponse
from .array_performance import ArrayPerformance
from .array_performance_response import ArrayPerformanceResponse
from .array_response import ArrayResponse
from .array_s3_performance import ArrayS3Performance
from .array_s3_performance_response import ArrayS3PerformanceResponse
from .array_space import ArraySpace
from .array_space_response import ArraySpaceResponse
from .blade import Blade
from .blade_response import BladeResponse
from .bucket import Bucket
from .bucket_response import BucketResponse
from ._built_in import BuiltIn
from .certificate import Certificate
from .certificate_response import CertificateResponse
from .client_performance import ClientPerformance
from .client_performance_response import ClientPerformanceResponse
from .directory_service import DirectoryService
from .directory_service_response import DirectoryServiceResponse
from .directory_service_role import DirectoryServiceRole
from .directory_service_roles_response import DirectoryServiceRolesResponse
from .dns import Dns
from .dns_response import DnsResponse
from .error_response import ErrorResponse
from .file_system import FileSystem
from .file_system_response import FileSystemResponse
from .file_system_snapshot import FileSystemSnapshot
from .file_system_snapshot_response import FileSystemSnapshotResponse
from .hardware import Hardware
from .hardware_connector import HardwareConnector
from .hardware_connector_response import HardwareConnectorResponse
from .hardware_response import HardwareResponse
from .link_aggregation_group import LinkAggregationGroup
from .link_aggregation_group_response import LinkAggregationGroupResponse
from .linkaggregationgroup import Linkaggregationgroup
from .log_download_response import LogDownloadResponse
from .login_response import LoginResponse
from .network_interface import NetworkInterface
from .network_interface_response import NetworkInterfaceResponse
from .nfs_rule import NfsRule
from .object_response import ObjectResponse
from .object_store_access_key import ObjectStoreAccessKey
from .object_store_access_key_response import ObjectStoreAccessKeyResponse
from .object_store_account import ObjectStoreAccount
from .object_store_account_response import ObjectStoreAccountResponse
from .object_store_user import ObjectStoreUser
from .object_store_user_response import ObjectStoreUserResponse
from .objectstoreaccesskey import Objectstoreaccesskey
from .pagination_info import PaginationInfo
from .protocol_rule import ProtocolRule
from .pure_array import PureArray
from .pure_error import PureError
from .pure_object import PureObject
from .reference import Reference
from ._resource import Resource
from .smb_rule import SmbRule
from .smtp import Smtp
from .smtp_response import SmtpResponse
from .snapshot_suffix import SnapshotSuffix
from .space import Space
from .subnet import Subnet
from .subnet_response import SubnetResponse
from .test_result import TestResult
from .test_result_response import TestResultResponse
from .version_response import VersionResponse
